
# q-expansion of newform 10.32.a.b, downloaded from the LMFDB on 26 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 10
weight = 32
poly_data = [-337159, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[0, 240], 1]]

hecke_ring_character_values = None
aps_data = [[-32768, 0], [14512122, 27], [-30517578125, 0], [6397579052606, -116265709], [-250453006061088, -177897667078], [-99720031150054198, 349460770724], [6079530163747350426, -39750856585796], [63700437798342706580, 185807759464888], [633451578093601560282, -1737438161003183], [-4592545588815416628930, 582428188036318696], [-73147921646107616125468, -678706186950045686], [-2398480093519378037050534, 345781604574961944], [7467809757150258130041942, -23195477792918290764], [14449507306674367791921842, 54985558657375243571], [-25806760852876323568603914, 832543868350745537891], [306226598668975040542754322, -1575414426760012069636], [2703547346806784780431567140, 4793962641247192019692], [1417938778120478833594939562, -36900397264287468255072], [5418797932114387296699101126, -116495408499467212572207], [29211218131835694725283917772, 6438309678972166826298], [85707228645867832747642424882, 403667852193346973583324], [94387969982720630170289480120, 2371894578199871965390908], [268286269655170514611592154162, -3799660893014807932230305], [-375136278723140341812080377590, -11126262716959530984138360], [-2113044879880684924025141826814, 6568440442827355053666100], [5311861292686641822797543106702, -51216673908605865292107784], [-12737658556106990426294475496078, -130900516838693889768418635], [10476753615738356622819246365406, -130809734566501402256347367], [-18241671139642539259174377273910, 328165835201959826267408024], [-9812817085353161090932130100198, 288818196269291887604629672], [201834986179322096690886944754446, 2854921373589311605772314623], [842274397943758115392194289830432, -257709067003758004806089594], [1421096511536249080143414024273666, -1166126021496942006232848144], [-634575811348468536798293265060940, -4685990062177975952532988668], [276944037563672396966734798722450, -2291354048862156708444017640], [-7546890031830335319635370013843348, 3365071102490426354185478970], [9137255206180808898639490050209906, 29420139739629895260302010056], [21958942878568037008876100635600802, -29352076912098423764884408145], [16932233528946937684319497839663726, 13505905310681338687637295763], [18200330481025942523897079110478882, 112020258201900203335447276760], [-52943402215419792600830006129365380, 206571577739910075350671975444], [27671100918654905524217992992844382, 25774016606118748178719340944], [-86010549438914757359644039518119508, 575006599217266344266916360118], [-69225591733861880060755947256056358, -1470541734537066271887729038820], [76550605467286605124516687717321386, 1483847442470087728362797764268], [-540466371935115971671355127300099400, -165194964766578343486185715264], [-1280042013854978190214289493523635088, -665156708269825111090050895450], [170124818747027440376780235915356282, -844598131401987048328215011387], [802398311320771797120869433102200046, -22293482708025693941678755645851], [1142569544292427907204976283552087670, 14910070114786454137564499295232], [3081587273279110451108384883575253162, 1934318619364863624680381657076], [7320205273937589824258437170533363160, -13691520700403307113594331312052], [-2947741505345334795270759455508178258, -4972186472697406831734220881980], [-12693541016695965616638271434198918048, 43699240033634255885756989703090], [-18361009082928730130673445532714076294, 9089589765942270320314076537704], [39228624594568059108939280566117144402, 154012787613992292469675203909533], [-2892918092313351227400696228636053670, -316384406642205101382254913298576], [-1616611703092061478400455330303087028, -203286689627716900828224787206714], [30566457809598583593211873227341815346, 342102719774465797505018420993656], [49047645827921029704859772223872752182, 938695925942043337959741621078140], [52996264259973250781928973122939668762, 354714754944646698880089615184783], [-46436653557970672354598225689778415558, -1573139990439571588155508924594320], [-131457987483895201128645680666414327194, 55447279226341809429141446097945], [314983764972843909145834470796743114612, 2779493209685392016044622640893374], [-53204502453675798266834424725073596998, 4762093310237945310345502947697096], [213842633383671477989242010773200793026, -5768890531456436978333677456204972], [20514149617396989488841773575826683832, -9229115531196915427094126185045938], [206837072995606100677055651079568004066, -9755060639284232819373391979752520], [863786265589735183116618366348446010486, 17189106119499519352008983768904717], [1348244838872127206427270595571158381550, -9222333338219506199714595082883088], [4356460528804676791728895119575021402322, -1475542050113088290518745901518136], [-2802651886917347013284719886296762988760, -34629062526175976111906291074344544], [-5386939423579316318447557268667732791674, 35276202908058220949837990047262259], [-2186829228608260267773146624506337458318, 19457916449696282062580362691350120], [-8769286702703750713602144591615336287380, 32028183654492473193301623354712216], [2324239660705891125055202864750337573162, 804714777135558588915185832371101], [-15223804016259050835070354374758540627790, 33205515756336126221376883274645872], [-9840299921848556022084993118927263209014, -104077556618437483529824092603785948], [-11383045051374360547720816767502597332798, -4378799141545870896969942105655776], [-33942220637209057538531870467330550524210, -129077988504188360727387963435310724], [-2331417612662501558437141990314344557620, 375544387457935623914401688775921172], [-17178045659511905613654647803407563802478, 53936957010215701819055100300534360], [-7844918564306321253875443783268000560068, -396223747310503697442311147639222610], [62794692680823402479127368536066778379362, 452971955765692921113691507051052276], [-4684569170456465563599145010813735191240, -25701328858031167613743288327533984], [10593647172158635375992486091023814983042, 950340717446824409234510475011157379], [-23214567545121155626480788009908462801850, -1132576631537578231843766079603525772], [130855682046983807861690365346335513112906, 455967560136533886673671505814438400], [-246098019011501788738402528585093267308138, 937673603118513091189232620445735640], [-260737511850127503801148781371862978879998, 552291092603063800640720520552060009], [-122194644577386201144966974106134249263674, -71523882401100005139506097571589607], [374098567693314798534851030915124674834520, 1969304927710986632551246605139376140], [150891588452660620153718765500499480305766, 191999318552556226008129475403423159], [404105045086625875810775912342491711908192, 2693962834257049614034090975518122594], [886389574262943487376357853739892566711700, -295092480293484675726879930145043184], [-8133548349772597442846358389674099228878, -1692017593758146981570717195482243859], [430226080678270569371547161004502828337790, 3401285372377490105258007955109831328], [-1645642155062824368712463005855077376878678, 2279558739183920702241179884478196480], [-1004377663485488281311633066285981581782918, 2436850238183501670879963606844459671], [-1648340527501192877290028726945195503269658, -11452199405184346358214806217631675192], [2669632492876732527066336734864210045422286, 14355323618847129299458825809875488149], [1638340046117122894444043135939431518939306, -33635890147571704891922284498864015128], [1468940006436185531380271583927036331321002, -6052150242654438457518587689514964949], [697071869060918231756416292534643785540430, 40846714236911607203300132910812002412], [3310022680420849851878523975534177745545272, 8756296904033481682951432109938672910], [2814379156432751093387964654418673916643946, 47883745501787193779932232995708028304], [12147741765177088594918653667049169474279966, 19250334199386942605454361513893579033], [-2670844508629150298710164538741410213276558, 68347886831884366821556831829789961824], [7703002953521954340419007913292826107553600, 20353733828935825555804186223084889564], [-8383384979193394639991944129984714862343898, 30161947739742479103712261073914124972], [9072381428727476397184830465545623167341606, -64786398563784979186622026359959649021], [-7015935076877091732179222551586234437492198, -146668961295559008816112354495155240588], [13037416470915713390738383363110891109843626, 116800670468016972466576208115129293220], [-17028613483304409644021070625095203212247620, 82811654513371628292854711933797816320], [8075800207930267730912716189288944305557532, 120244414937632902378494372650572412114], [32860992259220802168039155433602070128736942, -52111664175028259633054908883383205340], [15630437317163236150945284449737007421248042, 211218586572023831921096730656039990931], [28777715648206075522397945096611842901240086, -149151312955483724042002598172645128609], [37797189880051185963069638398069827509723922, 209957670622554410760997527832924739644], [29706935834382023581309003807780221652038540, -66280304757419958939973164090616422596], [917370041259356295295048225756428228087362, 66666808774221754453058174828709299184], [41266215276182006987044319682272795529424082, -379952257159093339089173370197318691060], [-26645323127337229610366650301364766916143254, -182143163834676562726614887032317688892], [-93375388655521808801303507751361706425150638, -309611642677666639754472364695362522957], [81504361356164206846765218444591821997131192, 155651628226502824651166010043869437130], [-17399429740192226589036403955998108404270198, 994731174197152195114737760309462599512], [-53673436211446799317101040845713254919578810, 227858231460980347182124549660863680488], [162324139983197554234387902794598682246174680, -489866137930995523330720095123302806980], [38055730877350580188465145218073878833767246, 2666430163968009033627989849511856257651], [-195318696906155081407065169493152035408074638, -1878437196526745832720861835905085493568], [75871964944111094142011027366899928817596060, 176040951265095324540636439606513101324], [-296481371269022051724611195967171975523287558, 1593985140337902326783889966280755033105], [-240423299905931271269340727830913922319376348, -2562647475881340833988026991605780325414], [45016438414344121499280933465925538787506306, -4808570324838347864093788473164149488336], [301106374322343093113150632881553023890688762, 3659947119481902737274438928793728497952], [461760722584196682479626655922603688902803330, 93962781263243516331888489495147886088], [-323687469544547299996332540608590536662574918, 4765367086854612667027226521836905549020], [-940320182846108538697605719304637763636866834, -915700241227747566415058725158614386659], [68853206539158927666908936435913870980700786, -1175032148717892648212006860918664761636], [804554332621315491109134064020527987110198890, -1487800747033247346180968244639497870592], [854122384928148872768294700979699180622852912, 551583294007020758049915645449385110242], [1490747002688970120758972078769487937793130722, -7191192863835479550352072133588672671576], [28945547926469193545716048271736327592556282, 18563448278424227690971783423974174552113], [757262662184242138932679895297858293670750646, 13201460928405156824658804231181247770397], [-1141213499740590687440601657237342987233279830, -8796700993801298506506639683287299547968], [1265537289360938028772545679042782527681627760, 9524663195776791266889841059764571717828], [1515672122279872459720433896908221425692596522, 3325521149318156624732662268088373374732], [-2406984631509139894836337788191717978421809694, -1222310526369424540130119416822751631272], [-2004517203635080612372769516545442997250325260, 18635947768634707465859296883290129092036], [-4204070044543338256594391598489554783775656598, 1607272762794272142628099890428639683621], [720605984638501676644419785349884303037188546, 44018028976669537044112728178979456667440], [-2135119383244113511765967018205331376999340018, 14037202105571310624239291741337969030780], [4649469432177043843406170849622077478223770762, -21312774736090509198112879581215927811605], [-2414051574346267706563414914691766047336586034, 18020748935614806823543158557344110584515], [-946439944531458502992835602011291289581466394, 10429641890092340934337673519412783511053], [-6790401242346079131110211606353016147386292588, 42748531866341515122594245062103264009130], [3494654767941189055005691954019173965983731280, 30897921206281187033909694119611434162756], [427779204914888621392985536266478014060141270, 62973165471787287843952153829500990140340], [9436289851896041842358062496117322244331581466, 16838598453473879073600104307137330065100], [-9802415362759307604135342326378155471532703258, 21025567997012175361961104457844007482784], [-49180054978446826605360239120922357210007914, -63822072400937286826904560889160443327935], [-3318607501656012930992005337647911566441217078, -30546770313453387275303861613420470133824], [7091169795726151036556309619746273544761667926, 181471409959707652591499216835187552751415], [-8076695185854212557980599693687510709627932328, 51219394375275112618562103800057864436910], [-19264630377692025503140796070514659302584459854, -21060411643925224906907783595217319042964], [6732957539362528723687029748965087445233013362, -115919784605102593347022898739733217500139], [-6718854104559484403331982220807968955176126108, 44542788814026129949094974218273975314850], [793185977928749041185108724772726989215042386, 61367262425014016143218918324427039442772], [-17967497543872251183629786994801635680821924910, -318126117081224821215013998133988436657384], [701160946964902320043543204506645551723878602, 436332955816627699187777204905933909409956], [-801546933107289249850382298819837661001675220, 181340381792735914132284304286054498513176], [-74119040389897296470074557716013931212617461978, 9888664627067091774914706891195398611776], [-25793868372734893641370587177793490243211665868, -229729637799358579890610382576197166929450], [-42465481392454539363143625509809355706237113038, -209052155106194792523105501736620693975532], [23848660487460773405122830582008841089961036560, 276444657874130905491505288454227737438656], [-70780370215071002492859847432099555930552695750, 98623291352204936571953473074032936236792], [1523578607484130123796974540815813045507223352, -243962887038854013230364180981416849260178], [20396585144008130472680628433556307471245195262, -716153809561923703325216131597212474107456], [-68512466056967725434627652776026983622327537398, -184183988400584838171278166283720267466287], [-17418487693716300831497763975039095405481650470, -584602692571461728925536461889744246906176], [-47402428880551435731030726602478121776309252634, -463286364758013501776889034922745013604549], [-18379746558578561962867572656507461067258461008, 525091388293806825104608236813305226756958], [7080987052680827920667603394712454406143799842, 923711677135724249509861377390380628063684], [38013805190004230146177699973326621057207642386, 513861185445424404320298882739203270072124], [-29757331400644805468824596257663013072008911878, 517237213318935995191019013446049096740341], [51533413268799557602891547902824115181244525990, -475720955598374202769971878279826698952296], [27610098561220242143812665423796075276167986426, -562046800675370412479579427400901298927048], [49134095446436276187089058723237376729838421482, -937261631276364901782091919029907193793133], [-21349706177522479708937147771051334287267790130, 1865402546700732519884728943793192379388332], [-125997234998909332482680763632946130255299743148, 2457094062246814039702383029736734128386170], [294057276828106727054666105261728290125816991722, 1181820336566938329661678775433067484287312], [240905957513414552435368872314363578691983678002, -685989882063676614808056461630607137631869], [-147964431143287767065769111702823552326817933528, 3077388918994794742460987449728000056416178], [404672548005880433898849310658621821237243191882, -1685674670712009741256225800949468614603600], [38619289298233508346383720114552181857807635566, -683869282502473341468761680404993533778699], [-53780555216648810197185323908617454649165923158, -6083144328572015552968806444133085051742724], [140687055539794010554388150237385031134363024302, -20793364052857924534981446651344332145268], [-754527472818879930972540748611971489812884381598, 1649335242248278410250570711549484424319716], [-161042972025535092819317323941208562174715279774, -226127903364912264716149751960449707959168], [-408400990175994514304066854568074216948264183518, -913573771578984035177253874915482621274723], [-226799152892444390787266757634449444556751535330, -700293094385674827877993842750350459426408], [898817364868063654705066833849632254016589323132, -2789539439394506474313683332359174065748522], [1123634647773367224920734850041941057010584411266, -3182907167461157774964502910050565830014828], [1515688018760831628534368144833957675790110072850, -2920942943545602919381226063129974100196672], [836696569837141971604013535193697128117553549940, -4634492366231373285881079952497328875984036], [-26986137891009954543519834957823759671736048254, 2833519997193053547252093479906684055032272], [-361712298052240139542057305937891785026046750880, 16164337618302012735832354021778624443239976], [-1240995009210161358439612985885743685545115382438, 2393520155149269438982101195158500190838683], [519224787139183648685811901168955408378662925610, 15453040621205407496197316004794221217620392], [-248414100094754326461235028505750049401095620408, 16978187191108655031462278345140694048412358], [358329927879334840517631893583962521126122627386, -12483950311388096738363449482969461829140540], [-1619525346402997779503115831853521055941648934398, -5146509487442436856877505847741622623999432], [191984206375812593401208903216803018518892205522, -10991714824675364424406977233866932283694379], [-2084620143123054098012796003014046113954614052994, 703317692240086747270368918130546597630689], [-189207393747615815668256995897345758128097807120, -13776627401228370870364850012788603421147620], [62798853187661029183951769754002203610379444422, 23827156914127026723014603133977193898343604], [-2463108143329271828958665817756309551757452442754, 16370644542335225027320941153839453859998063], [195086233184372013686828500055374080576066421362, -11652901859650253370530124459498030307777568], [2862179437748152171562216213227204702801117866126, 465290346507337705152292221296570123569195], [-5367884965542050370395950268864659449455439789318, 6896716405221199521630301665992001552197436], [1182730909621542287733061667209687345077178388882, 10192132374399100537720134969394891627440976], [-2840646014588220759899324212057196628452156629600, -13048907405433319683965540245538742162562524], [-9099604174868239165143639000020642506688573459310, 7976943522157083714903222407608805561214440], [1984453583210880305217190857484615362260122415282, 10386756577369071769892090762158165536242601], [468389251802099997711678821284499563997852853246, 61096429804746590560917315485294163775734741], [-3525905176725859629520288915872984040983140951230, 25551045405747492371472933266637331197158528], [8418743131681490761572234242907113384041468952562, -53693790513728457486756048037754616391574460], [-9186571833916730109092839411903099365032510778240, 16941603257739803083778193028681645752933528], [6852959242402341578011718468468624910427458081686, -12551593664192660754885536041629625331452313], [5186507143144534442261473009026823513837151377752, 69930153121765636734830449346943200040614398], [7681124375176574597994833553631282189919451146522, -16677843543955341431122086823885875898524868], [7108178418147645834168190793379945998008507841540, -49411281786700246988316893244827653525790808], [11414227232569258242270551662788150679053515441372, -3175697427979526445119778783544166722539394], [-6127030875495724101834368073978384735635881314618, -147590799906660544401546751329571876276659908], [11491651578369212178986656489070965973740207562762, 42222305819802817314473875236056009295851103], [-1467026408586704113915313397862749921072250158834, -175854990085306053732087811880559469061866313], [-16358237830397888953449688606026125451100391046490, -6622675270780221236356382043279584964858108], [18281501522914763625348117339269177203407204514242, 14595025793601094646465620553074031999423508], [535050596960831757858583345514105805469777605900, 88602863496016150523531312565544430831504544], [-12796334423757240179447622695028505391861851806588, 78542298417603582745566206561330413471678030], [11123877291096502610322521323690690755228133991682, -40154902076989948655496183089874216779353081], [-13167492164624260704036415737632972027529645782368, 44172517480049062474352102886354344114420418], [-12636775721837672110485376522829354727979476651958, 147911888577207373224286787141248724294793], [13438838718400969353733669221315269964384443660750, -263617474295912516293556663566096508781904944], [5927348703114310079648466807969204285142823782722, 89208792174112714931920535704025484468186152], [9727817533768163358250433470879838068090261126440, -153270530309665323542473112660813470426022568], [-49194710133987556447936766128137786512240145627874, 22795451492681821413546631162501444439704711], [-19915239394102511343620158991486850895788147955128, 213417024187402985863595079150013279093808978], [12890413666789607464525673314355407569548043952820, 269117868403558796798585072042264851774976476], [16199775294095688769242875990466295321820626552962, 151561772307973650033318362204954486167682729], [30311562971864030553875761727007223569979765527386, -55461252985036741386934949616826052363306652], [-52181079489090340087661358421217339936805127909998, -149817454882691551775063156556058077236564320], [17474486621212615278943190802051980081973268132806, 256075199326745799422568222024733648563128759], [4594655464880283768483054801982708479675456762590, 553605285944599309361027604122566537687923900], [66151632034956083008901585901034376036498635016802, 63996453387866834236910427463219203613651216], [51665411046732221022276690629220590099378060240580, -72698724386113378732310822446753479941707184], [-27740694545909535361971665143604052175525820042578, 97070872595595521514773797147873685663383512], [14172758874288410865047155240221927458331218901446, -289036703877588577216583151319356060028689147], [87379815949221221594635019663886351667963655440866, -136991085195585845260959313767840040473021704], [-87146102763476020210065206032462882222800100335094, 57301484511500380053214750060436573177596224], [-72754776760458673538957030106440072245918426740598, -404795710717328372213373528049489024827777083], [4333802528396815082525666856761040444313232337726, 535106860452708093014106673234907962671792957], [70142278334877585584357607863831742210296377851830, -711318284111879145356618882600896885620797088], [-139289210531294980946512289722645882904913858878758, 220023665215396961064433190181016704508847216], [82401931673219721077170846148486984950268935983786, -982247335599745535920879445081491613320870268], [-29233675063560900350992060508427213310294465145500, 699084536604411446837057176461183790746561696], [-92576157243457323765219187634998576578723442741410, 74768520151533558410642127203362547051194336], [114992845655864962897049129765750955506606895961722, 398798967387260448930844473729729602164798992], [-24442918769108198821722620137764683812235056461118, -77913635294042284800425512251234264108014589], [52825145685098821400796395131216957274133151050762, 1615789015586803498277676056243833965874487832], [105126501311092685131400888021399384146098380444342, -607433511846402055140263953325157891527431024], [114955687665297574897874962820379913497012714574886, 598169406467199243330475386406930864692019017], [93305955055811950269247163954906819789979049052522, -968545783781531233001177199291044365609560300], [-73585815308621554683285410956670735485561976773360, 1102835757935927413060062156280130007622741680], [-58925280517700506102512386643719542199563739003254, 1143094078459607359632221821105861076856033088], [-93660545239051546202138378477110792327613394070438, -297568606914677789634005704434656984331854583], [-132072235243268970555279467759024631754171721883834, -1471873733425660193209828003326904383044803643], [-200953847680066785768744747461157909743567097854290, -1966456367449789499299902776895088121292735224], [134829427176093384269551567372567183245646682565302, -301786711557387758493499456654977822839594228], [-205469411594882733392512499006280797227038015608688, 1764465942220016039497337302457763921976687310], [227496053867587430084533874226878591921967462077082, 1975554435789640906594011197308767773554635469], [-380023723368920601012486657138942233415584541044668, 1614152649357434259292877258773615305206920422], [-3655517201234112493518462441734744656408276858314, 1229540597638518963545956245089971446984066047], [-168253125714632805004305993102733960143047906036338, -2191752251678918934980045847565057338441352608], [690107578025735584944706514151796456873061110154126, -11270825558720260263941907345230019392018607], [435124677423145944823802805506907743103679909323972, -2635361895075844515980473944500002413982753910], [-551038986954276000093800100189871078984866085342918, 270337269069165821624366101589460980513526716], [344029714858391242320483823721783792160590489787546, 2697571662399989628571535420669396997718697348], [600911780255506600210958089436985914807633592827120, -3425928024859468896444126315793903623626105340], [650146686664306780148322375584390608841220550157910, -691623372254234842167312932591317572568342636], [-680659250992695524436103758055911869632855690240998, -1443405208490794390831226068279302306990402312], [424810351320574639937427817749155657941929185146206, 1588025040943466055944470674435248396655815317], [-781374334936767230756962868274643676020004925927198, -4203239553976620342672789048147352061145142252], [137935176908209200972505808711272773825615618110832, -656049921873359494411033568035691279756515766], [-900294611868571316180296696120556627174961805223038, 2098177180520677910392735523477359340412390912], [175683284366373870917667072996917056109831534091450, 7155844629194741508410786983226291548037954344], [-992967096860604561984101913852886124766986411866348, -3323064103967568875761047686450800471455398630], [330046243762602061621687845808252789737952106970282, -660471123492011661418381149616465067806111920], [118207465325432697014433251357984050870042942420620, 2510771473290017457971906493993814717639431504], [-616664760464707846427735107034999757162846849330634, 8868514820219269966456602263328774678626879769], [1619231710447357307373476657779032975752165928443042, 1150198099749416692260320294985450602782830624], [68870028795773785593346021368809087717189634022386, -5188991210071523484090886316222597687665003432], [-792986605342144079049967284228571324650048456740200, -11554178186962172566755411052187812395307402636], [869590631165762276483312715077663455779736437689322, 3236846601522340117510918901372261264688364395], [55783432081882026939060902940898646967168231211712, 6253846812314046361701856591052302296093375090], [751806750600881092912273455947635007059146832573826, 10814815877856405387059792317819624508913409916], [130035673837738173288968585841539739046791288441846, 6740955799146349268700397414655470858315357989], [864958924484069899576028913086978773531810557939470, -2332239024612640543531183593751273701383383512], [-1003780950120644942482956604567319442421752580698840, 7768197735571083138720252810238124356954094664], [1938515780057884709499809300199673006884970962439322, -10729993944160253599147467196338870661167083352], [982960053365181325659027038932627809494760294664602, -2711911629344531075755340501734910662087248307], [-257726158597522758492031271666053102258801835028570, 821505928499160973690753522386446916558455120], [323281363811813546260754969350884308841522149598882, -3899493304659898096133862420293217195123045424], [-120889440783372269566247703456991230747716054867638, -21886389613610185831113446814764211130884061517], [-942858376383295902847340529380683632191888250920034, -20028659502870158522217467280295697604863732085], [-1912992572469782131933900697444434188767578464779590, 8307691843671583718948478159390014649436529720], [-810848049644213506795070402320337276074672997268300, -11424688997623781714697329114616072114483437800], [-603477024251063995825647964193527180468614865586988, -14546795501117916691399843346766010591532590558], [1502298007172421359201260800265536265759676412639002, 12003970529803937878946569924062206729163595816], [-963811995714825791649008006419090773777593731142730, -23176299691838884444959888173465973250865809420], [782153521564957462063244110270706763152572310223032, -5188277193245590071620827944931182634717635702], [-1808660205627959317602800576964378521751260504767534, -18540220212046644946301500330297658366655407536], [1455119756361086309300071419566294500598122829162442, 5755022837457545600325607078331643205316835744], [2313564190545750096134198828175162342421481635068242, -18801160120468903807697252522059278808317504647], [525793675453983955863438381197752255673530654965522, 17831670920601202655127927311389043023435079400], [1244461043671812144320705035962282073409133904507262, -55221648679328243987685248851376117935871311212], [5258136496984315325679955577346867128992859037178820, -11831486039701978367093352094501959119315731056], [2804846284406222730872097852093977294036936675448722, 18471467150917761453664737863196503269797256155], [-1388698589137352781383877588708821069361128510299194, 36744324135118905661395250433445391765378793635], [812723935489841299409284853403801409284309585534402, -55734669935427539135431847891850368866899143980], [4455155760649724777838644944132705486874430120792122, -38983446310430686459339709319664933229367317160], [-1158994245887054091775649631901373721740277144459534, -32315845540064651649928118669766651531119991072], [4960355633457773178618461453814307504126277352752360, 16776288259661199256563406908501672044906783380], [-4513906642229185517618888629667318091399412041023358, -64440777417447995515775992385136348147598797729], [-2079053961380384530310724250790786655865643737223248, 55611527344881845028032460824372134348495479258], [-8303797819238451630222314281545550868338959435907074, -16898286732842491755151936575281851838195919903], [-1445642563582347411442078824573902479029591984741670, -5745510396509383513150800417688290904548773688], [-16320536229005399762483980204882375097042416996233318, -23991773133706255809042397531130779922018984064], [-2077867944397871284657045740155900676917462837197018, -86414946417913549520866564696348537798372710052], [-5450088374363827400400248751236807572367525038369234, 29851637920135565993015089666941233328240062559], [690001009590024680656923506420316361340090125802042, -108467343981351041125376491427033273694519410720], [8210811203640629789701421767804674416624877833140986, -95777336255900889072650862433392499050116033184], [-10978786379876912435599694351741908005045791077838910, -55388181879006478758418722298789162943150180664], [19497131244133537882278504706115919650621585143949612, -9779428020048309442066761084504192942900073534], [-6473629235143022359425308280791535035204195928493638, -40117956901910430571838468968579223932912935064], [4631338256867095768593423975070791330877931967654660, 103396580043129349790613697685075061660121387216], [-5489819581806318047398650276914040158284406003255758, -10667190827609266428811701175324264146128865504], [19370889783170116381119411208901136985254649487576486, 80163759399567136277506418829406037205695183021], [-22139719680661880542030689835873713271425890349641148, 61610022253715097188359980421247849789932646570], [-10879081895487589771098501583456883855710994805469494, 34038135028835748486624764129902817740023251644], [3682956817806194109795742642819330523961684212438672, -25338192850074756967656944421211709534420817994], [6199560697151980967774842022348051285069742067981946, 37931822367140347061705123719104226579069085448], [-11685606014726517688941968635365882893691146247578118, 95198902006155230365159442007414136670954204000], [9370201811476178533798980524905279791144227675601362, -3331808978193769094491863575504725446628841943], [-8783143019052702941602003848174859855155863267070490, 115803441910582845049421382498260250880647521568], [-34044590312692296938128870218848218396940078573428158, -64202709665617314390779683947869875887830006132], [-23342556712750414518866425580444964115628234027838600, -104890619369618596654336421903955034997433852748], [7611304900648025086511090917491206493988638040707912, -201609203612348334166553014441527551334858332810], [9965978875645329699956030454762534703617328645003026, 113452263827911141277467362170528625177793117340], [-10513145234763347810380243648249194232342664080330518, 124550579833393715572155745890071369088583951041], [8792243637694209373404731199536708043394016045460866, -213105012450265700223792724026510096503435385836], [12004481498008614067156440995444025151210650476187642, 176461763849243478977253785391906076831567926048], [-14615917760102647752496391983473184596468276196636314, -107328140670214882947540649177134403198728487917], [24417616873571055362270748943495503506879954364421140, 225658391167060415788212702776797967632463924060], [417159313498247914873930905523650792380217638711726, 233869609944964752860795821312223332030746553749], [48350764973816502360212307033645593911723881118037882, -136940913982530793154920918501504805684109966676], [7313585865204090983060026490435641387774651604311146, 120741247502014174255302408650560119813315363180], [-13720178678930929506572243792267693740679568105672478, -129578083469374863172875239032624168014402184731], [-32599614738950135725324991318637089632182205958495578, 504979808946771855645058840280108844841562471972], [33053091540835268258933889691246228308389958986506032, -46782215888909398859550603898405028080829139914], [-16821700284461165596087554469929911730075575352271540, -686449530555762835490450977486988541178202060848], [6786991971127620994727506602571531260564326258487042, 314908640088963564260754448689426011375496003449], [-21144669044135996909860261465253064721907007520745550, 216250344344438175729889115857579445119588747528], [-69864126661628389572611354059703872409290013690138548, 224334123904294168492673456164855695131493664026], [8741690019885230943113128550589881315458657013810906, -639039312231105804960276641786866428883839156620], [43890763618118039973318400019701923745591735806190020, -162127012644013713544610660692571662931998736368], [-138383576843609438417121857822555791528337564086334508, -110508709069775817469729425916801458225653171350], [-67961607836028084198322757181501376941273734666075758, 628793849423921396558587312758119395531171907072], [1725032412538721782296374582983761548243021721012390, 390623158178209398589967683449514930224870861700], [-27406066124575553503974209749976378517818423163275374, 419544437240309956823070170273015063453278675512], [149862563049929750728586369314976316410067959347574022, 133428583906077572607238444085287767558104344064], [-41986207456859420961841760788934063257053733755091038, -1044876302663861386357939233934469531321311671304], [-48014970597488238730915892403826176463613986102012714, -162404817793865946779990913546237375367313488209], [12375502353579169794544056226208959909258293364442706, 1008040636325442827553773296529961854450572209712], [43925002963390616546573904254144100398828098937008340, 1295490090419877543534910452550441195987155683640], [66669735532228666405561052080918834234118233179163002, -660336963020978088663235719849364545322264633463], [-4808491691929211292463287369873641506792072395277828, -927558765414951055204242446822546168185351945338], [189738830884058419879105268814083002121108457055944746, 457380759502131311105518211772358764013710098376], [110717798720467305670906881137864690334464067503288162, 783667968040123241914669819184687343487988021571], [-124399864829454598824676000239518834049264532473663834, 41748552152300292943948675045954123278286546563], [184363463027569601483545302888833682758355184614736310, 436430176138417973295273753304542257853295607380], [28768517744090711157741880319914497146125866027079842, -536701418176704062611051512440849815780502875688], [31186167429137224263483812923556180896244870328393300, 171098215490452982185438683401465064202032974164], [20323492245876643113210165602223207578165480277662006, -1616243492563304365083089820522320797989758584559], [28969981399530871614701813018143326107645552347534812, 1717011440539029069511164984431222460752652868266], [-134169188836419298265341209578158377337841814833781598, -456923879382389384900010171278425279058949850752], [-64018553418771008735037854751346538353500698331250120, -891673581623820111659301460270074784967979766580], [-191323357008430110560248976954175839056483446962887830, -99150335162866948021596258535458414209892806016], [169344244376454600735876959024259524718815425410036032, -1174952359784507735390925016267224104288568163510], [-245068244624677372442269720040410709739619480737817758, -21989305527511107363498180439190928451306229264], [9551975532602889745161922379191662384645707985345050, -209046025119995393501385124281494878082731428072], [-8495924690307428203191267308440623839986878672658278, 20804372721966438383962670455962459142269271892], [-224260640980984541094612203442897319405179462651158074, 701799126822618872086621440239829237854067256291], [71920569558310905053420576091450820522613866536053346, -490064890262759567303209456101163780621375483904], [-261610944768488765452986988777497734262630175467033390, -744040599795045126162385329009515095973630396192], [-72126450627209348248478326311706182194744134501489108, 449412493921979764245621315431544540152442594234], [348783922930073862291204488443029751985802383624023586, 803852697562134238230929126305998528517090799020], [164877694076535973512118225631060508125609120534359602, -2339066904156086150042023586614060113846441008432], [69108050483091922585543448182742984695281594963783122, -2297665432619606616815721542976912698985599136225], [-84312277747331228918012341775900738737065904142728020, -631500807527946689214828648326330363444755478196], [-292930189555359481969388151520149793118179500712831438, 1096425962655726806713692398892076843349405695624], [106251942356813178949121841699135666402773741221729866, -3162079745018795359368342871908592472219458200616], [481594220413999082876610634433004520281743967575840442, 242177151487764813193985963804995987370547065999], [-97018591646605311276217362043076271507449365012498048, 1398337966408481340307956918213311679416323723494], [543238413834429652571093476892388612847066467438323906, -454145059552711305546032001632989662816391422964], [-186490173662786810979652155981786472751136243727622538, 2327117582951317107304983709253443912345853224568], [-66192810288833585085259499009323471599759013850976480, 627100689136615928353171343856273752992587395240], [383695997087164162137991326270765641686863063996271166, -2022630022663171857216584240007015697784236332821], [-210247961678752571763956260080614569546839314987714814, -265702289966105726174514078784564147905667372172], [202913384856424776005886619399288793627933736323682522, 2052974814609190831742098340425959599517788609849], [-232371781405134719020772291371431566755994166650701110, 1697719970728867618028221087762014854832495058192], [368157563792100148637893834085406427864739456721427226, 1201358987333983627044234605382547465445530795268], [-120246664544446612431179695746527500644517002491260554, -2970546802876726601076063632436394516951608528045], [468169294428929682590813168166542325448964630136708660, -4624466856542739369532679483296535129122206118460], [105707410062819334761585638975654168978959685973350522, 898320643487493767898447237742895776584248154912], [-9865457527137893936339496476289670085908721466471294, 4436832280521804063933451728953839944430609928616], [-125926654828277413762480440941390126735294380893608598, 5759664904754556226211171400573700419275689419], [-202996483400553893049706731339815875109593832339756370, -2884402424566552148655693506825158739084129656276], [-44573384426693816239677741408025822258737062962596328, 7219090254388223807281998768500949969438534677454], [1308852193370902396405165314976208548269159456546000600, -1344868826530147513179436140728532234967861535336]]
